@@ -14,22 +14,22 @@ from .duffel_payments.payment_intents import PaymentIntentClient, PaymentIntentC
 from .notifications.webhooks import WebhookClient
 
 __all__ = [
-    AircraftClient,
-    AirportClient,
-    AirlineClient,
-    OfferRequestClient,
-    OfferRequestCreate,
-    OfferClient,
-    OrderChangeClient,
-    OrderChangeOfferClient,
-    OrderChangeRequestClient,
-    OrderClient,
-    OrderCreate,
-    OrderUpdate,
-    OrderCancellationClient,
-    PaymentClient,
-    PaymentIntentClient,
-    PaymentIntentCreate,
-    SeatMapClient,
-    WebhookClient,
+    "AircraftClient",
+    "AirportClient",
+    "AirlineClient",
+    "OfferRequestClient",
+    "OfferRequestCreate",
+    "OfferClient",
+    "OrderChangeClient",
+    "OrderChangeOfferClient",
+    "OrderChangeRequestClient",
+    "OrderClient",
+    "OrderCreate",
+    "OrderUpdate",
+    "OrderCancellationClient",
+    "PaymentClient",
+    "PaymentIntentClient",
+    "PaymentIntentCreate",
+    "SeatMapClient",
+    "WebhookClient",
 ]
