@@ -11,7 +11,7 @@ class AircraftClient(HttpClient):
 
     def get(self, id_):
         """GET /air/aircraft/:id"""
-        return Aircraft(self.do_get("{}/{}".format(self._url, id_))["data"])
+        return Aircraft.from_json(self.do_get(f"{self._url}/{id_}")["data"])
 
     def list(self, limit=50):
         """GET /air/aircraft"""
