@@ -6,4 +6,4 @@ from .fixtures import raw_fixture
 def test_offer_model_parsing():
     name = "get-offer-by-id"
     with raw_fixture(name) as fixture:
-        assert Offer(fixture["data"])
+        assert Offer.from_json(fixture["data"])
